@@ -1,5 +1,4 @@
-%% -*- coding: latin-1 -*-
-%% Copyright (C) 2003 Joakim Greben <jocke@gleipnir.com>.
+%% Copyright (C) 2003 Joakim Grebenö <jocke@gleipnir.com>.
 %% All rights reserved.
 %%
 %% Copyright (C) 2006 Gaspar Chilingarov <nm@web.am>
@@ -118,7 +117,7 @@ handle_payload(Args, Handler, Type) ->
     PL = unicode:characters_to_list(Args#arg.clidata),
     {Payload,DecodedStr} =
         case RpcType of
-            T when T==haxe; T==json ->
+            T when T==haxe ->
                 ?Debug("rpc ~p call ~p~n", [T, PL]),
                 {PL, yaws_api:url_decode(PL)};
             soap_dime ->
