@@ -409,7 +409,8 @@ get_url_file(Fname) ->
     {ok, binary_to_list(Bin)}.
 
 get_remote_url_file(URL) ->
-    case httpc:request(URL) of
+    HttpOptions = [{ssl, [{verify, verify_none}]}],
+    case httpc:request(get, {URL, []}, HttpOptions, []) of
         {ok,{{_HTTP,200,_OK}, _Headers, Body}} ->
             {ok, Body};
         {ok,{{_HTTP,RC,Emsg}, _Headers, _Body}} ->
@@ -447,11 +448,13 @@ inets_request(URL, SoapAction, Request, Options, Headers, ContentType) ->
                  end,
     NewOptions = [{cookies, enabled}|Options],
     httpc:set_options(NewOptions),
+    HttpOptions = [{timeout,?HTTP_REQ_TIMEOUT},
+                   {ssl, [{verify, verify_none}]}],
     case httpc:request(post,
                        {URL,NewHeaders,
                         ContentType,
                         Request},
-                       [{timeout,?HTTP_REQ_TIMEOUT}],
+                       HttpOptions,
                        [{sync, true}, {full_result, true},
                         {body_format, string}]) of
         {ok,{{_HTTP,200,_OK},ResponseHeaders,ResponseBody}} ->
